@@ -638,6 +638,7 @@ var DefaultStopWords = []string{
 	"jbos",
 	"jekyll",
 	"jenkin",
+	"jetbrains",
 	"job-",
 	"job.",
 	"job_",
@@ -1181,6 +1182,7 @@ var DefaultStopWords = []string{
 	"smart",
 	"smtp",
 	"snake",
+	"snapshot",
 	"snippet",
 	"soap",
 	"social",
